CheckoutDetailResponse class
Constructors
- CheckoutDetailResponse({String? subMerchantId, String? displayName, dynamic logoFileUrl, String? description, bool? icaAllowed, bool? mcaAllowed, String? checkoutBackgroundColor, String? checkoutTextColor, bool? fastPaymentEnabled, bool? otherPaymentEnabled, bool? continueBtnIsWhite, bool? orderSummaryEnabled, dynamic paymentExperience, num? checkoutSessionDuration, bool? changeUserAllowed, bool? enableDesktopView, bool? tokenizationEnabled})
- CheckoutDetailResponse.fromJson(dynamic json)
Properties
- changeUserAllowed ↔ bool?
-
getter/setter pair
- checkoutBackgroundColor ↔ String?
-
getter/setter pair
- checkoutSessionDuration ↔ num?
-
getter/setter pair
- checkoutTextColor ↔ String?
-
getter/setter pair
- continueBtnIsWhite ↔ bool?
-
getter/setter pair
- description ↔ String?
-
getter/setter pair
- displayName ↔ String?
-
getter/setter pair
- enableDesktopView ↔ bool?
-
getter/setter pair
- fastPaymentEnabled ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icaAllowed ↔ bool?
-
getter/setter pair
- logoFileUrl ↔ dynamic
-
getter/setter pair
- mcaAllowed ↔ bool?
-
getter/setter pair
- orderSummaryEnabled ↔ bool?
-
getter/setter pair
- otherPaymentEnabled ↔ bool?
-
getter/setter pair
- paymentExperience ↔ dynamic
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subMerchantId ↔ String?
-
getter/setter pair
- tokenizationEnabled ↔ bool?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited